@@ -44,7 +44,7 @@ class VonMises(YieldFunction):
             (princ[:, 1] - princ[:, 2])**2
         )
 
-        value = np.sqrt(diff_sq_sum / 2) - kwargs['equivalent_stress']
+        value = (np.sqrt(diff_sq_sum / 2) / kwargs['equivalent_stress']) - 1
 
         return value
 
@@ -70,7 +70,7 @@ class Tresca(YieldFunction):
             (princ[:, 0] - princ[:, 2]),
             (princ[:, 1] - princ[:, 2]),
         ])
-        value = np.max(diff, axis=0) - kwargs['equivalent_stress']
+        value = (np.max(diff, axis=0) / kwargs['equivalent_stress']) - 1
 
         return value
 
@@ -141,12 +141,6 @@ class Barlat_Yld91(YieldFunction):
         G = stress_states[:, 2, 0]
         H = stress_states[:, 0, 1]
 
-        # print('A')
-        # print(A)
-
-        # print('B')
-        # print(B)
-
         aA = a * A
         bB = b * B
         cC = c * C
@@ -154,12 +148,6 @@ class Barlat_Yld91(YieldFunction):
         gG = g * G
         hH = h * H
 
-        # print('aA')
-        # print(aA)
-
-        # print('bB')
-        # print(bB)
-
         # Stress deviator invariants:
         I_2 = (
             ((fF**2 + gG**2 + hH**2) / 3) +
@@ -176,39 +164,23 @@ class Barlat_Yld91(YieldFunction):
             )
         )
 
-        # print('I_2')
-        # print(I_2)
+        with np.errstate(invalid='ignore'):
+            # For hydrostatic stresses, I_2 will be zero, so theta will be np.nan:
+            theta = np.arccos(I_3 / I_2**(3/2))
 
-        # print('I_3')
-        # print(I_3)
+        finite_idx = np.isfinite(theta)
 
-        theta = np.arccos(I_3 / I_2**(3/2))
+        Phi_1 = (+2 * np.cos(((2 * theta[finite_idx]) + np.pi) / 6))**exponent
+        Phi_2 = (+2 * np.cos(((2 * theta[finite_idx]) - (3 * np.pi)) / 6))**exponent
+        Phi_3 = (-2 * np.cos(((2 * theta[finite_idx]) + (5 * np.pi)) / 6))**exponent
 
-        # print('theta: ')
-        # print(theta)
+        # Where theta is np.nan, Phi is zero:
+        Phi = np.zeros(stress_states.shape[0])
+        Phi[finite_idx] = (
+            ((3 * I_2[finite_idx])**(exponent / 2)) * (Phi_1 + Phi_2 + Phi_3)
+        )
 
-        Phi_1 = (+2 * np.cos(((2 * theta) + np.pi) / 6))**exponent
-        Phi_2 = (+2 * np.cos(((2 * theta) - (3 * np.pi)) / 6))**exponent
-        Phi_3 = (-2 * np.cos(((2 * theta) + (5 * np.pi)) / 6))**exponent
-
-        # print('Phi_1: ')
-        # print(Phi_1)
-
-        # print('Phi_2: ')
-        # print(Phi_2)
-
-        # print('Phi_3: ')
-        # print(Phi_3)
-
-        Phi = ((3 * I_2)**(exponent / 2)) * (Phi_1 + Phi_2 + Phi_3)
-
-        value = (Phi / 2)**(1 / exponent) - equivalent_stress
-
-        # print('value:')
-        # print(value)
-
-        # w = np.where(np.abs(value) < 0.1)[0]
-        # print('w: {}'.format(w))
+        value = (((Phi / 2)**(1 / exponent)) / equivalent_stress) - 1
 
         return value
 
@@ -327,7 +299,7 @@ class Barlat_Yld2000_2D(YieldFunction):
 
         phi = phi_prime + phi_dprime
 
-        value = (phi / 2)**(1 / exponent) - equivalent_stress
+        value = (((phi / 2)**(1 / exponent)) / equivalent_stress) - 1
 
         return value
 
@@ -529,8 +501,7 @@ class Barlat_Yld2004_18p(YieldFunction):
         princ_sum_terms = np.array(princ_sum_terms).T
 
         princ_sum = np.sum(princ_sum_terms, axis=-1)
-
-        value = (princ_sum / 4) ** (1 / exponent) - equivalent_stress
+        value = (((princ_sum / 4) ** (1 / exponent)) / equivalent_stress) - 1
 
         return value
 
@@ -562,7 +533,7 @@ class Hosford(YieldFunction):
             (princ[:, 1] - princ[:, 2])**exponent
         )
 
-        value = ((diff_sq_sum / 2)**(1 / exponent)) - equivalent_stress
+        value = (((diff_sq_sum / 2)**(1 / exponent)) / equivalent_stress) - 1
 
         return value
 
@@ -627,15 +598,15 @@ class Hill1979(YieldFunction):
         princ = np.sort(np.linalg.eigvals(stress_states), axis=-1)[:, ::-1]
 
         diff_exp_sum = (
-            f * (princ[:, 1] - princ[:, 2])**exponent +
-            g * (princ[:, 2] - princ[:, 0])**exponent +
-            h * (princ[:, 0] - princ[:, 1])**exponent +
-            a * ((2 * princ[:, 0]) - princ[:, 1] - princ[:, 2])**exponent +
-            b * ((2 * princ[:, 1]) - princ[:, 2] - princ[:, 0])**exponent +
-            c * ((2 * princ[:, 2]) - princ[:, 0] - princ[:, 1])**exponent
+            f * np.abs(princ[:, 1] - princ[:, 2])**exponent +
+            g * np.abs(princ[:, 2] - princ[:, 0])**exponent +
+            h * np.abs(princ[:, 0] - princ[:, 1])**exponent +
+            a * np.abs((2 * princ[:, 0]) - princ[:, 1] - princ[:, 2])**exponent +
+            b * np.abs((2 * princ[:, 1]) - princ[:, 2] - princ[:, 0])**exponent +
+            c * np.abs((2 * princ[:, 2]) - princ[:, 0] - princ[:, 1])**exponent
         )
 
-        value = diff_exp_sum**(1/exponent) - equivalent_stress
+        value = ((diff_exp_sum ** (1 / exponent)) / equivalent_stress) - 1
 
         return value
 
@@ -653,6 +624,7 @@ class Hill1948(YieldFunction):
         'L',
         'M',
         'N',
+        'equivalent_stress',
     ]
 
     LITERATURE_VALUES = {
@@ -672,7 +644,7 @@ class Hill1948(YieldFunction):
         }
     }
 
-    def __init__(self, F, G, H, L, M, N):
+    def __init__(self, F, G, H, L, M, N, equivalent_stress):
 
         self.F = F
         self.G = G
@@ -680,6 +652,7 @@ class Hill1948(YieldFunction):
         self.L = L
         self.M = M
         self.N = N
+        self.equivalent_stress = equivalent_stress
 
     @staticmethod
     @yield_function_fitter
@@ -697,10 +670,15 @@ class Hill1948(YieldFunction):
             N * 2 * stress_states[:, 0, 1]**2
         )
 
-        value = diff_sq_sum - 1
+        value = ((diff_sq_sum ** (1 / 2)) / kwargs['equivalent_stress']) - 1
 
         return value
 
+    @property
+    def lankford(self):
+        'Get the Lankford coefficient (R-value)'
+        return self.H / self.G
+
 
 class Dummy2DYieldFunction(YieldFunction):
     'Dummy 2D yield function that resembles a cylinder about the z-axis.'
@@ -717,8 +695,7 @@ class Dummy2DYieldFunction(YieldFunction):
     @yield_function_fitter
     def residual(fitting_params, stress_states, fitting_param_names, **kwargs):
 
-        # princ = np.sort(np.linalg.eigvals(stress_states), axis=-1)[:, ::-1]
-        princ = np.linalg.eigvals(stress_states)
+        princ = np.sort(np.linalg.eigvals(stress_states), axis=-1)[:, ::-1]
 
         # r = 10.4:
         # value = (np.sqrt(np.abs(princ[:, 0]**2 + princ[:, 1]**2)) / kwargs['radius']) - 1
